# Maintainer notes

## Releasing a new version

This project is [released on PyPi](https://pypi.org/project/libcoveocds/). [Follow these instructions](https://ocds-standard-development-handbook.readthedocs.io/en/latest/coding/#release-process) to release a new version.
